{
	"name" : "Project Management",
	"version": "0.1",
	"author" : "Tiny",
	"website" : "http://tinyerp.com/module_project.html",
	"category" : "Generic Modules/Projects & Services",
	"depends" : ["base", "sale", "account", "hr", "mrp"],
	"init_xml" : [],
	"demo_xml" : ["project_demo.xml"],
	"update_xml": ["project_data.xml", "project_wizard.xml", "project_view.xml", "project_report.xml", "project_workflow.xml"],
	"active": True
}
